from datetime import datetime
from typing import List, Optional, Dict, Any

from janis_core import *
from janis_core.types.common_data_types import String, File, Boolean, Int

Anvi_Mcg_Classifier_V0_1_0 = CommandToolBuilder(tool="anvi_mcg_classifier", base_command=["anvi-mcg-classifier"], inputs=[ToolInput(tag="in_profile_db", input_type=String(optional=True), prefix="--profile-db", doc=InputDocumentation(doc="Anvi'o profile database")), ToolInput(tag="in_contigs_db", input_type=String(optional=True), prefix="--contigs-db", doc=InputDocumentation(doc="Anvi'o contigs database generated by 'anvi-gen-\ncontigs'")), ToolInput(tag="in_output_file_prefix", input_type=File(optional=True), prefix="--output-file-prefix", doc=InputDocumentation(doc="A prefix to be used while naming the output files (no\nfile type extensions please; just a prefix).")), ToolInput(tag="in_collection_name", input_type=String(optional=True), prefix="--collection-name", doc=InputDocumentation(doc="Collection name.")), ToolInput(tag="in_bin_id", input_type=String(optional=True), prefix="--bin-id", doc=InputDocumentation(doc="Bin name you are interested in.")), ToolInput(tag="in_bin_ids_file", input_type=File(optional=True), prefix="--bin-ids-file", doc=InputDocumentation(doc="Text file for bins (each line should be a unique bin\nid).")), ToolInput(tag="in_exclude_samples", input_type=File(optional=True), prefix="--exclude-samples", doc=InputDocumentation(doc="List of samples to exclude for the analysis.")), ToolInput(tag="in_include_samples", input_type=File(optional=True), prefix="--include-samples", doc=InputDocumentation(doc="List of samples to include for the analysis.")), ToolInput(tag="in_gen_figures", input_type=Boolean(optional=True), prefix="--gen-figures", doc=InputDocumentation(doc="For those of you who wish to dig deeper, a collection\nof figures could be created to allow you to get\ninsight into how the classification was generated.\nThis is especially useful to identify cases in which\nyou shouldn't trust the classification (for example\ndue to a large number of outliers). NOTICE: if you ask\nanvi'o to generate these figures then it will\nsignificantly extend the execution time. To learn\nabout which figures are created and what they mean,\ncontact your nearest anvi'o developer, because\ncurrently it is a well-hidden secret.")), ToolInput(tag="in_get_samples_stats_only", input_type=Boolean(optional=True), prefix="--get-samples-stats-only", doc=InputDocumentation(doc="If you only wish to get statistics regarding the\noccurrence of bins in samples, then use this flag.\nEspecially when dealing with many samples or large\ngenomes, gene stats could be a long time to compute.\nBy using this flag you could save a lot of computation\ntime.")), ToolInput(tag="in_overwrite_output_destinations", input_type=Boolean(optional=True), prefix="--overwrite-output-destinations", doc=InputDocumentation(doc="Overwrite if the output files and/or directories\nexist.")), ToolInput(tag="in_genome_detection_uncertainty", input_type=Int(optional=True), prefix="--genome-detection-uncertainty", doc=InputDocumentation(doc="Determines the range of sample detection values that\nare considered negative, ambiguous or positive. Min of\n0 and smaller than 0.5, default of 0.25. For exmaple\nfor the default samples with detection below 0.5-0.25\n= 0.25 will be considered negative (i.e. donot contain\nthe genome), samples with detection between 0.25 and\n0.75 would be ambiguous (and hence would not be used\nfor the classification), and samples with detection\nabove 0.75 would be considered positive (i.e. contain\nthe genome).")), ToolInput(tag="in_outliers_threshold", input_type=Int(optional=True), prefix="--outliers-threshold", doc=InputDocumentation(doc="Threshold to use for the outlier detection. The\ndefault value is '1.5'. Absolute deviation around the\nmedian is used. To read more about the method please\nrefer to: 'How to Detect and Handle Outliers' by Boris\nIglewicz and David Hoaglin\n(doi:10.1016/j.jesp.2013.03.013).")), ToolInput(tag="in_zeros_are_outliers", input_type=Boolean(optional=True), prefix="--zeros-are-outliers", doc=InputDocumentation(doc="If you want all zero coverage positions to be treated\nlike outliers then use this flag. The reason to treat\nzero coverage as outliers is because when mapping\nreads to a reference we could get many zero positions\ndue to accessory genes. These positions then skew the\naverage values that we compute.\n"))], outputs=[ToolOutput(tag="out_output_file_prefix", output_type=File(optional=True), selector=InputSelector(input_to_select="in_output_file_prefix", type_hint=File()), doc=OutputDocumentation(doc="A prefix to be used while naming the output files (no\nfile type extensions please; just a prefix)."))], container=None, version="v0.1.0")


if __name__ == "__main__":
    # or "cwl"
    Anvi_Mcg_Classifier_V0_1_0().translate("wdl", allow_empty_container=True)

